@@ -18,7 +18,10 @@ def console_main():
         data_before_after = dict(sorted(data_before_after.items(), key=lambda x: x[0]))
         requests = Api(reader.get_url(), reader.get_privatetoken())
 
-        testrun_id = requests.create_testrun(JSONFixture.create_testrun(reader.get_project_id(), f'AllureRun {datetime.today().strftime("%d %b %Y %H:%M:%S")}'))
+        if reader.specified_testrun:
+            testrun_id = reader.specified_testrun
+        else:
+            testrun_id = requests.create_testrun(JSONFixture.create_testrun(reader.get_project_id(), f'AllureRun {datetime.today().strftime("%d %b %Y %H:%M:%S")}'))
 
         for history_id in data_tests:
             prefix = '' if 'uuid' in data_tests[history_id] else '@'
